#include "SYScmx.h"
#include "TTYcmx.h"
#include "IOScmx.h"

#include "YASKarm.h"

#include "HEARTsvc.c"


// MK 2015/04/12: Added define for NGX LPC800 Minikit board
// Chip is LPC810 - DIP8 - 4 K Flash, 4K RAM

// MK 2015/03/15: Added define for KMS C214AA XSBO Board
// Chip is LPC812 XSON16 package

//#define TARGET_LPCXPRESSO_LPC812
//#define TARGET_LPC800_MINIKIT
#define TARGET_C214AA_XSBO_LPC812_XSON16

#define HBEAT_PORT	0

#if defined(TARGET_LPC800_MINIKIT)
#warning "*********** Building for Target LPC800 MINIKIT  ***********"
#define HBEAT_BIT	2
#define HBEAT_LOGIC	FALSE
#elif defined(TARGET_LPCXPRESSO_LPC812) // LPCxpresso_LPC812 board
#warning "*********** Building for Target LPCXpresso LPC812  ***********"
#define HBEAT_BIT	7
#define HBEAT_LOGIC	FALSE
#elif defined(TARGET_C214AA_XSBO_LPC812_XSON16)
#warning "*********** Building for Target C214AA XSBO LPC812  ***********"
#define HBEAT_BIT	12
#define HBEAT_LOGIC	FALSE
#endif

//inline void app_main(void);
void	c214a_board_init();
short c214a_toggle( YASK_MSG_T *msg);

inline void app_main(void)
{
	// Init système

	SYSinit( SYS_CLOCK_MODE_OSC_PLL, (ulong) 12E6, (ulong) 60E6, (ulong) 30E6);

#if defined(TARGET_C214AA_XSBO_LPC812_XSON16)
	c214a_board_init();
#endif

	// Setup du service de heart beat
	HEARTsvc_setup( HBEAT_PORT, HBEAT_BIT, HBEAT_LOGIC);

	// Paramétrage
	HEARTsvc_param(10, 80, 10, 400);

	// Démarrage
	HEARTsvc_start();

#if defined(TARGET_C214AA_XSBO_LPC812_XSON16)
	YASKstart( c214a_toggle);
#endif

#ifndef TARGET_LPC800_MINIKIT
	//printf("YASKarm_test_LPC812 Starting...\r\n");
#endif
}

//-----------------------------------------------------------------------------
// Basic setup for C214A board (LPC812 XSON16)
//-----------------------------------------------------------------------------


void c214a_board_init()
{
	IOSset_out( 0, 0); // UART0_RXD
	IOSset_out( 0, 1); // Clockout
	IOSset_out( 0, 4); // UART0_TXD
	IOSset_out( 0, 6);
	IOSset_out( 0, 7);
	IOSset_out( 0, 8);
	IOSset_out( 0, 9);
	IOSset_out( 0, 10);
	IOSset_out( 0, 11);
	IOSset_out( 0, 12);
	IOSset_out( 0, 13);

	//-----------------------------------------------------------------------------

	// PIO0_1 = CLKOUT
	// Sends 100 KHz on PIO0_1 - Pin 18 of XSBO - C214A

	LPC_SWM->PINASSIGN8 &= ~(0xff << 16);
	LPC_SWM->PINASSIGN8 |= (1 << 16);

	LPC_SYSCON->CLKOUTDIV = 120;

	//-----------------------------------------------------------------------------



} // End of c214A_board_init()

//-----------------------------------------------------------------------------
// Basic I/O test for C214A board (LPC812 XSON16)
//-----------------------------------------------------------------------------

short c214a_toggle( YASK_MSG_T *msg)
{
	static char me = YASK_NONE;
	static boolean toggle = FALSE;

	if( msg)
	{
		switch(msg->idn)
		{
		case 0:
			if( toggle)
			{
				toggle = FALSE;
				IOSset_bit( 0, 0);
				IOSset_bit( 0, 1);
				IOSset_bit( 0, 4);
				IOSset_bit( 0, 6);
				IOSset_bit( 0, 7);
				IOSset_bit( 0, 8);
				IOSset_bit( 0, 9);
				IOSset_bit( 0, 10);
				IOSset_bit( 0, 11);
			//	IOSset_bit( 0, 12); // Run LED
				IOSset_bit( 0, 13);
			}
			else
			{
				toggle = TRUE;
				IOSreset_bit( 0, 0);
				IOSreset_bit( 0, 1);
				IOSreset_bit( 0, 4);
				IOSreset_bit( 0, 6);
				IOSreset_bit( 0, 7);
				IOSreset_bit( 0, 8);
				IOSreset_bit( 0, 9);
				IOSreset_bit( 0, 10);
				IOSreset_bit( 0, 11);
		//		IOSreset_bit( 0, 12); // Run LED
				IOSreset_bit( 0, 13);
			}
			break;
		}
	}
	else
	{
		me = YASKregister( c214a_toggle, "c214a_toggle");
		YASKpst( me, 0, 0, -50);
	}

	return 0;

} // End of short c214a_toggle( YASK_MSG_T *msg)

//-----------------------------------------------------------------------------
